﻿#Sample Usage :  Remove-ExpAndSuperseded.ps1 <CAS Server Name> <Sitecode> '<Target SUP Group>'

$sdkserver = $args[0]
$SiteCode = $args[1]
$SUPGroupName = $args[2]


	


Function Expired
{
try
{
	
    Write-Host "Preparing to remove Expired Updates..." -ForegroundColor Green	
	Write-Host "Querying Software Update Group information..."
	$SUPGroup = gwmi -computername "$sdkserver" -Namespace "root\sms\site_$SiteCode" -query "SELECT * FROM SMS_AuthorizationList where LocalizedDisplayName = '$SUPGroupName'"

	if ($SUPGroup -eq $null)
	{
		Write-Host "Invalid Software Update Group $SUPGroupName, no action taken" -ForegroundColor red
		Exit
	}
	else { $SUPGroupID = $SUPGroup.CI_ID }

	Write-Host "Querying updates information..."
	$updates = gwmi -computername $sdkserver -Namespace "root\sms\site_$SiteCode" -query "SELECT upd.* FROM SMS_SoftwareUpdate upd, SMS_CIRelation cr WHERE cr.FromCIID= $SUPGroupID AND cr.RelationType=1 AND upd.CI_ID=cr.ToCIID"

	Write-Host "Preparing updated Software Update Group removing expired..."
	foreach($upd in $updates)
	{
		if ($upd.IsExpired -eq $true) { continue }
		$SUPGroup.Updates += $upd.CI_ID
	}


	if ($SUPGroup.Updates.Length -eq $updates.Length) 
	{
		Write-Host "Software Update Group $SUPGroupName does not have any Expired Software Update, no action taken" -ForegroundColor red
		Exit
	}

	Write-Host "Updating Software Update Group..."
	$SUPGroup.Put() | Out-Null
	Write-Host "Software Update Group $SUPGroupName updated successfully..."
}
finally
{ 
	Write-Host "Complete. Press any key to continue ..."
	$x = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
}
}


Function Superseded
{
	
try
{
    Write-Host "Preparing to remove Superseded Updates..." -ForegroundColor Green	
    Write-Host "Querying Software Update Group information..."
    
	$SUPGroup = gwmi -computername "$sdkserver" -Namespace "root\sms\site_$SiteCode" -query "SELECT * FROM SMS_AuthorizationList where LocalizedDisplayName = '$SUPGroupName'"

	if ($SUPGroup -eq $null)
	{
		Write-Host "Invalid Software Update Group $SUPGroupName, no action taken" -ForegroundColor red
		Exit
	}
	else { $SUPGroupID = $SUPGroup.CI_ID }

	Write-Host "Querying updates information..."
	$updates = gwmi -computername $sdkserver -Namespace "root\sms\site_$SiteCode" -query "SELECT upd.* FROM SMS_SoftwareUpdate upd, SMS_CIRelation cr WHERE cr.FromCIID= $SUPGroupID AND cr.RelationType=1 AND upd.CI_ID=cr.ToCIID"

	Write-Host "Preparing updated Software Update Group removing superseded..."
	foreach($upd in $updates)
	{
		if ($upd.IsSuperseded -eq $true) { continue }
		$SUPGroup.Updates += $upd.CI_ID
	}


	if ($SUPGroup.Updates.Length -eq $updates.Length) 
	{
		Write-Host "Software Update Group $SUPGroupName does not have any Superseded Software Update, no action taken" -ForegroundColor red
		Exit
	}

	Write-Host "Updating Software Update Group..."
	$SUPGroup.Put() | Out-Null
	Write-Host "Software Update Group $SUPGroupName updated successfully..."
}
finally
{ 
	Write-Host "Complete. Press any key to continue ..."
	$x = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
}
}



Clear-Host
  
$ConfirmRole = Read-Host "What do you want to do? 
  E - Expired Updates
  S - Superseded Updates
  B - Both
  [E/S/B] "
	If ($ConfirmRole -like "E")

		{
			Expired{}
		}
		
	ElseIf ($ConfirmRole -like "S")
		{
			Superseded{}
		}
	ElseIf ($ConfirmRole -like "B")
		{
			Expired{}
			Superseded{}
		}

Exit
